| CopyStrategy | R Documentation |
Extend this class to implement a custom copy strategy.
execute()Copy project files according to the strategy
CopyStrategy$execute(original_dir)
original_dirThe original directory to copy from
planThe current test plan
The path to the temporary directory
clone()The objects of this class are cloneable with this method.
CopyStrategy$clone(deep = FALSE)
deepWhether to make a deep clone.
Other CopyStrategy:
PackageCopyStrategy,
default_copy_strategy()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.