FullTestStrategy: Run all tests for a mutant

FullTestStrategyR Documentation

Run all tests for a mutant

Description

This test strategy tells if a mutant is caught by any test.

To get faster results, especially for big codebases, use ?FileTestStrategy instead.

Super class

muttest::TestStrategy -> FullTestStrategy

Methods

Public methods


Method new()

Initialize

Usage
FullTestStrategy$new(
  load_helpers = TRUE,
  load_package = c("source", "none", "installed")
)
Arguments
load_helpers

Whether to load test helpers

load_package

The package loading strategy


Method execute()

Execute the test strategy

Usage
FullTestStrategy$execute(path, plan, reporter)
Arguments
path

The path to the test directory

plan

The current mutation plan. See muttest_plan().

reporter

The reporter to use for test results

Returns

The test results


Method clone()

The objects of this class are cloneable with this method.

Usage
FullTestStrategy$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

Other TestStrategy: FileTestStrategy, TestStrategy, default_test_strategy()


muttest documentation built on May 14, 2026, 5:10 p.m.