MultiReporter: Combine Several Mutation Reporters

MultiReporterR Documentation

Combine Several Mutation Reporters

Description

Fans out every reporter event to a list of child reporters, so a single muttest() run can drive more than one reporter at once – for example a live ProgressMutationReporter alongside a JSONMutationReporter that writes a machine-readable artifact.

Super class

muttest::MutationReporter -> MultiReporter

Public fields

reporters

List of child reporters.

Methods

Public methods

Inherited methods

Method new()

Initialize a combined reporter

Usage
MultiReporter$new(...)
Arguments
...

One or more MutationReporter objects.


Method start_reporter()

Start reporter

Usage
MultiReporter$start_reporter(plan = NULL)
Arguments
plan

The complete mutation plan


Method start_file()

Start testing a file

Usage
MultiReporter$start_file(filename)
Arguments
filename

Path to the file being mutated


Method start_mutator()

Start testing with a specific mutator

Usage
MultiReporter$start_mutator(mutator)
Arguments
mutator

The mutator being applied


Method add_result()

Add a mutation test result

Usage
MultiReporter$add_result(...)
Arguments
...

Arguments forwarded to each child's add_result().


Method update()

Update status

Usage
MultiReporter$update(force = FALSE)
Arguments
force

Passed to each child


Method end_mutator()

End testing with current mutator

Usage
MultiReporter$end_mutator()

Method end_file()

End testing current file

Usage
MultiReporter$end_file()

Method end_reporter()

End reporter

Usage
MultiReporter$end_reporter()

Method get_score()

Get the score (from the first child)

Usage
MultiReporter$get_score()

Method print()

Print each child that supports printing

Usage
MultiReporter$print()

Method clone()

The objects of this class are cloneable with this method.

Usage
MultiReporter$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

Other MutationReporter: JSONMutationReporter, MutationReporter, ProgressMutationReporter, default_reporter()


muttest documentation built on July 21, 2026, 5:09 p.m.