call_name: Mutate a function call name

View source: R/mutator-call.R

call_nameR Documentation

Mutate a function call name

Description

Replaces a function name in a call expression with another name. Useful for swapping semantically related functions such as any/all, min/max, or sum/prod.

Usage

call_name(from, to)

Arguments

from

The function name to replace.

to

The function name to replace with.

Examples

call_name("any", "all")
call_name("min", "max")
call_name("sum", "prod")


muttest documentation built on May 14, 2026, 5:10 p.m.