string_fill: Mutate the empty string literal to a placeholder string

View source: R/mutator-string.R

string_fillR Documentation

Mutate the empty string literal to a placeholder string

Description

Replaces "" with a fill string (default "mutant") so that code paths that depend on an empty string can be detected.

Usage

string_fill(fill = "mutant")

Arguments

fill

The replacement string. Defaults to "mutant". Override when the codebase already contains "mutant" as a meaningful value.

Value

A Mutator object.

Examples

string_fill()
string_fill(fill = "PLACEHOLDER")

muttest documentation built on May 14, 2026, 5:10 p.m.