| FileTestStrategy | R Documentation |
This strategy tells if a mutant is caught by a test matching the source file name.
For example, if the source file name is foo.R, and there are test files named test-foo.R or test-bar.R,
only test-foo.R will be run.
This strategy should give faster results than ?FullTestStrategy, especially for big codebases,
but the score might be less accurate.
muttest::TestStrategy -> FileTestStrategy
new()Initialize the FileTestStrategy
FileTestStrategy$new(
load_helpers = TRUE,
load_package = c("source", "none", "installed")
)load_helpersWhether to load test helpers
load_packageThe package loading strategy
execute()Execute the test strategy
FileTestStrategy$execute(path, plan, reporter)
pathThe path to the test directory
planThe current mutation plan. See muttest_plan().
reporterThe reporter to use for test results
The test results
clone()The objects of this class are cloneable with this method.
FileTestStrategy$clone(deep = FALSE)
deepWhether to make a deep clone.
Other TestStrategy:
FullTestStrategy,
TestStrategy,
default_test_strategy()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.