Skip to contents

This test strategy tells if a mutant is caught by any test.

To get faster results, especially for big codebases, use ?FileTestStrategy instead.

See also

Super class

muttest::TestStrategy -> FullTestStrategy

Methods


Method new()

Initialize

Usage

FullTestStrategy$new(
  load_helpers = TRUE,
  load_package = c("source", "none", "installed")
)

Arguments

load_helpers

Whether to load test helpers

load_package

The package loading strategy


Method execute()

Execute the test strategy

Usage

FullTestStrategy$execute(path, plan, reporter)

Arguments

path

The path to the test directory

plan

The current mutation plan. See muttest_plan().

reporter

The reporter to use for test results

Returns

The test results


Method clone()

The objects of this class are cloneable with this method.

Usage

FullTestStrategy$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.