| FullTestStrategy | R Documentation |
This test strategy tells if a mutant is caught by any test.
To get faster results, especially for big codebases, use ?FileTestStrategy instead.
muttest::TestStrategy -> FullTestStrategy
new()Initialize
FullTestStrategy$new(
load_helpers = TRUE,
load_package = c("source", "none", "installed")
)load_helpersWhether to load test helpers
load_packageThe package loading strategy
execute()Execute the test strategy
FullTestStrategy$execute(path, plan, reporter)
pathThe path to the test directory
planThe current mutation plan. See muttest_plan().
reporterThe reporter to use for test results
The test results
clone()The objects of this class are cloneable with this method.
FullTestStrategy$clone(deep = FALSE)
deepWhether to make a deep clone.
Other TestStrategy:
FileTestStrategy,
TestStrategy,
default_test_strategy()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.