| PackageCopyStrategy | R Documentation |
It copies all files and directories from the original directory to a temporary directory.
muttest::CopyStrategy -> PackageCopyStrategy
execute()Copy project files, excluding hidden and temp directories
PackageCopyStrategy$execute(original_dir, plan)
original_dirThe original directory to copy from
planThe current test plan
The path to the temporary directory
clone()The objects of this class are cloneable with this method.
PackageCopyStrategy$clone(deep = FALSE)
deepWhether to make a deep clone.
Other CopyStrategy:
CopyStrategy,
default_copy_strategy()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.