Skip to contents

Extend this class to implement a custom test strategy.

Methods


Method execute()

Execute the test strategy

Usage

TestStrategy$execute(path, plan, reporter)

Arguments

path

The path to the test directory

plan

The current mutation plan. See muttest_plan().

reporter

The reporter to use for test results

Returns

The test result


Method clone()

The objects of this class are cloneable with this method.

Usage

TestStrategy$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.