| TestStrategy | R Documentation |
Extend this class to implement a custom test strategy.
execute()Execute the test strategy
TestStrategy$execute(path, plan, reporter)
pathThe path to the test directory
planThe current mutation plan. See muttest_plan().
reporterThe reporter to use for test results
The test result
clone()The objects of this class are cloneable with this method.
TestStrategy$clone(deep = FALSE)
deepWhether to make a deep clone.
Other TestStrategy:
FileTestStrategy,
FullTestStrategy,
default_test_strategy()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.