| call_name | R Documentation |
Replaces a function name in a call expression with another name.
Useful for swapping semantically related functions such as any/all,
min/max, or sum/prod.
call_name(from, to)
from |
The function name to replace. |
to |
The function name to replace with. |
call_name("any", "all")
call_name("min", "max")
call_name("sum", "prod")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.